@@ -337,20 +337,6 @@ get_window_slot_for_location (NautilusApplication *self,
     return slot;
 }
 
-static void
-new_window_show_callback (GtkWidget *widget,
-                          gpointer   user_data)
-{
-    NautilusWindow *window;
-
-    window = NAUTILUS_WINDOW (user_data);
-    nautilus_window_close (window);
-
-    g_signal_handlers_disconnect_by_func (widget,
-                                          G_CALLBACK (new_window_show_callback),
-                                          user_data);
-}
-
 void
 nautilus_application_open_location_full (NautilusApplication     *self,
                                          GFile                   *location,
@@ -463,23 +449,6 @@ real_open_location_full (NautilusApplication     *self,
 
     g_assert (target_window != NULL);
 
-    /* close the current window if the flags say so */
-    if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND) != 0)
-    {
-        if (gtk_widget_get_visible (GTK_WIDGET (target_window)))
-        {
-            nautilus_window_close (active_window);
-        }
-        else
-        {
-            g_signal_connect_object (target_window,
-                                     "show",
-                                     G_CALLBACK (new_window_show_callback),
-                                     active_window,
-                                     G_CONNECT_AFTER);
-        }
-    }
-
     /* Application is the one that manages windows, so this flag shouldn't use
      * it anymore by any client */
     flags &= ~NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
@@ -912,23 +881,12 @@ const static GActionEntry app_entries[] =
 static void
 nautilus_init_application_actions (NautilusApplication *app)
 {
-    const gchar *debug_no_app_menu;
     GAction *sidebar_action;
 
     g_action_map_add_action_entries (G_ACTION_MAP (app),
                                      app_entries, G_N_ELEMENTS (app_entries),
                                      app);
 
-    debug_no_app_menu = g_getenv ("NAUTILUS_DEBUG_NO_APP_MENU");
-    if (debug_no_app_menu)
-    {
-        DEBUG ("Disabling app menu GtkSetting as requested...");
-        g_object_set (gtk_settings_get_default (),
-                      "gtk-shell-shows-app-menu", FALSE,
-                      NULL);
-    }
-
-
 
     sidebar_action = g_action_map_lookup_action (G_ACTION_MAP (app),
                                                  "show-hide-sidebar");
@@ -945,7 +903,14 @@ nautilus_init_application_actions (NautilusApplication *app)
                                   variant_set_mapping,
                                   NULL, NULL);
 
-    nautilus_application_set_accelerator (G_APPLICATION (app), "app.show-hide-sidebar", "F9");
+    nautilus_application_set_accelerator (G_APPLICATION (app),
+                                          "app.clone-window", "<Primary>n");
+    nautilus_application_set_accelerator (G_APPLICATION (app),
+                                          "app.help", "F1");
+    nautilus_application_set_accelerator (G_APPLICATION (app),
+                                          "app.quit", "<Primary>q");
+    nautilus_application_set_accelerator (G_APPLICATION (app),
+                                          "app.show-hide-sidebar", "F9");
 }
 
 static void
