@@ -29,8 +29,6 @@ typedef enum
     CHANGE_FILE_CHANGED,
     CHANGE_FILE_REMOVED,
     CHANGE_FILE_MOVED,
-    CHANGE_POSITION_SET,
-    CHANGE_POSITION_REMOVE
 } NautilusFileChangeKind;
 
 typedef struct
@@ -147,38 +145,6 @@ nautilus_file_changes_queue_file_moved (GFile *from,
     nautilus_file_changes_queue_add_common (queue, new_item);
 }
 
-void
-nautilus_file_changes_queue_schedule_position_set (GFile    *location,
-                                                   GdkPoint  point,
-                                                   int       screen)
-{
-    NautilusFileChange *new_item;
-    NautilusFileChangesQueue *queue;
-
-    queue = nautilus_file_changes_queue_get ();
-
-    new_item = g_new (NautilusFileChange, 1);
-    new_item->kind = CHANGE_POSITION_SET;
-    new_item->from = g_object_ref (location);
-    new_item->point = point;
-    new_item->screen = screen;
-    nautilus_file_changes_queue_add_common (queue, new_item);
-}
-
-void
-nautilus_file_changes_queue_schedule_position_remove (GFile *location)
-{
-    NautilusFileChange *new_item;
-    NautilusFileChangesQueue *queue;
-
-    queue = nautilus_file_changes_queue_get ();
-
-    new_item = g_new (NautilusFileChange, 1);
-    new_item->kind = CHANGE_POSITION_REMOVE;
-    new_item->from = g_object_ref (location);
-    nautilus_file_changes_queue_add_common (queue, new_item);
-}
-
 static NautilusFileChange *
 nautilus_file_changes_queue_get_change (NautilusFileChangesQueue *queue)
 {
@@ -234,21 +200,6 @@ pairs_list_free (GList *pairs)
     g_list_free_full (pairs, g_free);
 }
 
-static void
-position_set_list_free (GList *list)
-{
-    GList *p;
-    NautilusFileChangesQueuePosition *item;
-
-    for (p = list; p != NULL; p = p->next)
-    {
-        item = p->data;
-        g_object_unref (item->location);
-    }
-    /* delete the list and the now empty structs */
-    g_list_free_full (list, g_free);
-}
-
 /* go through changes in the change queue, send ones with the same kind
  * in a list to the different nautilus_directory_notify calls
  */
@@ -257,9 +208,7 @@ nautilus_file_changes_consume_changes (gboolean consume_all)
 {
     NautilusFileChange *change;
     GList *additions, *changes, *deletions, *moves;
-    GList *position_set_requests;
     GFilePair *pair;
-    NautilusFileChangesQueuePosition *position_set;
     guint chunk_count;
     NautilusFileChangesQueue *queue;
     gboolean flush_needed;
@@ -269,7 +218,6 @@ nautilus_file_changes_consume_changes (gboolean consume_all)
     changes = NULL;
     deletions = NULL;
     moves = NULL;
-    position_set_requests = NULL;
 
     queue = nautilus_file_changes_queue_get ();
 
@@ -292,27 +240,17 @@ nautilus_file_changes_consume_changes (gboolean consume_all)
         else
         {
             flush_needed = additions != NULL
-                           && change->kind != CHANGE_FILE_ADDED
-                           && change->kind != CHANGE_POSITION_SET
-                           && change->kind != CHANGE_POSITION_REMOVE;
+                           && change->kind != CHANGE_FILE_ADDED;
 
             flush_needed |= changes != NULL
                             && change->kind != CHANGE_FILE_CHANGED;
 
             flush_needed |= moves != NULL
-                            && change->kind != CHANGE_FILE_MOVED
-                            && change->kind != CHANGE_POSITION_SET
-                            && change->kind != CHANGE_POSITION_REMOVE;
+                            && change->kind != CHANGE_FILE_MOVED;
 
             flush_needed |= deletions != NULL
                             && change->kind != CHANGE_FILE_REMOVED;
 
-            flush_needed |= position_set_requests != NULL
-                            && change->kind != CHANGE_POSITION_SET
-                            && change->kind != CHANGE_POSITION_REMOVE
-                            && change->kind != CHANGE_FILE_ADDED
-                            && change->kind != CHANGE_FILE_MOVED;
-
             flush_needed |= !consume_all && chunk_count >= CONSUME_CHANGES_MAX_CHUNK;
             /* we have reached the chunk maximum */
         }
@@ -352,13 +290,6 @@ nautilus_file_changes_consume_changes (gboolean consume_all)
                 g_list_free_full (changes, g_object_unref);
                 changes = NULL;
             }
-            if (position_set_requests != NULL)
-            {
-                position_set_requests = g_list_reverse (position_set_requests);
-                nautilus_directory_schedule_position_set (position_set_requests);
-                position_set_list_free (position_set_requests);
-                position_set_requests = NULL;
-            }
         }
 
         if (change == NULL)
@@ -397,28 +328,6 @@ nautilus_file_changes_consume_changes (gboolean consume_all)
             }
             break;
 
-            case CHANGE_POSITION_SET:
-            {
-                position_set = g_new (NautilusFileChangesQueuePosition, 1);
-                position_set->location = change->from;
-                position_set->set = TRUE;
-                position_set->point = change->point;
-                position_set->screen = change->screen;
-                position_set_requests = g_list_prepend (position_set_requests,
-                                                        position_set);
-            }
-            break;
-
-            case CHANGE_POSITION_REMOVE:
-            {
-                position_set = g_new (NautilusFileChangesQueuePosition, 1);
-                position_set->location = change->from;
-                position_set->set = FALSE;
-                position_set_requests = g_list_prepend (position_set_requests,
-                                                        position_set);
-            }
-            break;
-
             default:
             {
                 g_assert_not_reached ();
